#!/bin/bash

DOC='release-notes'
BASEDIR=`pwd`
DOCDIR="$BASEDIR/$DOC"

git clone git://git.fedoraproject.org/git/docs/$DOC.git

echo 'renaming PO files'
cd $DOCDIR/po
git mv bn_IN.po bn-IN.po
git mv ca.po ca-ES.po
git mv cs.po cs-CZ.po
git mv da.po da-DK.po
git mv de.po de-DE.po
git mv el.po el-GR.po
git mv es.po es-ES.po
git mv fi.po fi-FI.po
git mv fr.po fr-FR.po
git mv gu.po gu-IN.po
git mv he.po he-IL.po
git mv hi_IN.po hi-IN.po
git mv hr.po hr-HR.po
git mv hu.po hu-HU.po
git mv id.po id-ID.po
git mv it.po it-IT.po
git mv ja.po ja-JP.po
git mv ms.po ms-MY.po
git mv nb.po nb-NO.po
git mv nl.po nl-NL.po
git mv pa.po pa-IN.po
git mv pl.po pl-PL.po
git mv pt_BR.po pt-BR.po
git mv pt.po pt-PT.po
git mv ru.po ru-RU.po
git mv sk.po sk-SK.po
git mv sr_Latn.po sr_Latn-RS.po
git mv sr.po sr-RS.po
git mv sv.po sv-SE.po
git mv ta.po ta-IN.po
git mv uk.po uk-UA.po
git mv zh_CN.po zh-CN.po
git mv zh_TW.po zh-TW.po
git commit -m 'rename PO files to $lang-$country style'



echo 'Adding existing languages to Makefile'
cd $DOCDIR
patch < ../add_existing_langs.patch
git add Makefile
git commit -m 'added existing languages (from ./po/) to OTHER_LANGS'



echo 'Adding RH languages to Makefile'
cd $DOCDIR
patch < ../add_rh_langs.patch
git add Makefile
git commit -m 'added additional Red Hat languages to OTHER_LANGS'



echo 'Adding pot dir and POT files'
cd $DOCDIR
make update-pot
git add pot
git commit -m 'added pot directory and POT files'



OTHER_LANGS=`cat Makefile|grep "^OTHER_LANGS"|sed 's/^OTHER_LANGS[ \t]*=[ \t]*//'`
echo 'adding PO dir and POs for each language'
cd $DOCDIR
make update-po-all
rm pot/messages.mo
for i in $OTHER_LANGS
do
  git add $i
done
git commit -m 'added PO dir and POs for each language in OTHER_LANGS'



echo 'merge previous translations'
cd $DOCDIR
POFILES=`ls pot/*.pot|sed 's/\.pot//'|sed 's/pot\///'`
for lang in $OTHER_LANGS
do
  # use a compendium for this language if it exists
  COMP=''
  if [ -s "po/$lang.po" ]
  then
     COMP="-C po/$lang.po"
  fi

  for f in $POFILES
  do
   msgmerge $COMP -o $lang/$f.po $lang/$f.po pot/$f.pot
  done
done
git commit -a -m 'merged previous translations from po/$lang.po'



echo 'All done!'


